==> haskell-dependent-map-0.4.0.0-333-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dependent-map
version:              0.4.0.0
visibility:           public
id:                   dependent-map-0.4.0.0-E0UrmcEmsYE8Ns1CpIAhMB
key:                  dependent-map-0.4.0.0-E0UrmcEmsYE8Ns1CpIAhMB
license:              LicenseRef-OtherLicense
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/dependent-map
synopsis:             Dependent finite maps (partial dependent products)
description:
    Provides a type called @DMap@ which generalizes
    @Data.Map.Map@, allowing keys to specify the type
    of value that can be associated with them.

category:             Data, Dependent Types
abi:                  edbc151eb7d2eb1e0d6c304b75f097df
exposed:              True
exposed-modules:
    Data.Dependent.Map Data.Dependent.Map.Internal
    Data.Dependent.Map.Lens

hidden-modules:       Data.Dependent.Map.PtrEquality
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dependent-map-0.4.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dependent-map-0.4.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dependent-map-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-map
hs-libraries:         HSdependent-map-0.4.0.0-E0UrmcEmsYE8Ns1CpIAhMB
depends:
    base-4.17.2.1 constraints-extras-0.4.0.2-3aRLOiCk05vFSGiSMPErrC
    containers-0.6.7 dependent-sum-0.7.2.0-EUdcqPEBhz9DGOuvwYdjBF

haddock-interfaces:
    /usr/share/doc/haskell-dependent-map/html/dependent-map.haddock

haddock-html:         /usr/share/doc/haskell-dependent-map/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dependent-map-0.4.0.0-334-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dependent-map
version:              0.4.0.0
visibility:           public
id:                   dependent-map-0.4.0.0-GVTfr5Nb5YvJxeo8O7qEK3
key:                  dependent-map-0.4.0.0-GVTfr5Nb5YvJxeo8O7qEK3
license:              LicenseRef-OtherLicense
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/dependent-map
synopsis:             Dependent finite maps (partial dependent products)
description:
    Provides a type called @DMap@ which generalizes
    @Data.Map.Map@, allowing keys to specify the type
    of value that can be associated with them.

category:             Data, Dependent Types
abi:                  b10aabbe5f2b3ad37d6a86e82e4f0dff
exposed:              True
exposed-modules:
    Data.Dependent.Map Data.Dependent.Map.Internal
    Data.Dependent.Map.Lens

hidden-modules:       Data.Dependent.Map.PtrEquality
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dependent-map-0.4.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dependent-map-0.4.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dependent-map-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-map
hs-libraries:         HSdependent-map-0.4.0.0-GVTfr5Nb5YvJxeo8O7qEK3
depends:
    base-4.17.2.1 constraints-extras-0.4.0.2-AHqGJokDSW8GWtigJv4eC9
    containers-0.6.7 dependent-sum-0.7.2.0-JIlIZFoiCv4HmLim3g0fqd

haddock-interfaces:
    /usr/share/doc/haskell-dependent-map/html/dependent-map.haddock

haddock-html:         /usr/share/doc/haskell-dependent-map/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
